.. MUSE documentation master file, created by
   sphinx-quickstart on Mon Aug  5 15:27:19 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================================
ModUlar energy system Simulation Environment: MUSE
==================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :numbered:
   :titlesonly:

   Glossary <glossary>
   Getting Help <getting-help>
   MUSE Overview <overview>
   Key MUSE Components <muse-components>
   Application Flow <application-flow>
   installation/index
   Running MUSE <running-muse-example>
   inputs/index
   user-guide/index
   advanced-guide/index
   developer-guide
   faq
   api
   release-notes/index


Indices and tables
------------------


- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
